@@ -1,4 +1,4 @@
-output_table <- function(pkgs.df) {
+output_table <- function(pkgs.df, include.RStudio = FALSE) {
 
   pkgs.df$Citation <- lapply(pkgs.df$citekeys,
                              function(x) {
@@ -9,6 +9,14 @@ output_table <- function(pkgs.df) {
 
   pkgs.df <- pkgs.df[, c("pkg", "version", "Citation")]
   names(pkgs.df) <- c("Package", "Version", "Citation")
+
+  if (include.RStudio) {
+    rstudio <- data.frame(Package = "RStudio",
+                          Version = as.character(rstudioapi::versionInfo()$version),
+                          Citation = "@rstudio")
+    pkgs.df <- rbind(pkgs.df, rstudio)
+  }
+
   return(pkgs.df)
 
 }
